@@ -6,28 +6,29 @@
 #'
 #' @param x A (grouped) data frame.
 #' @param dv Name of the dependent variable, for which the mean value, grouped
-#'        by \code{grp}, is computed.
+#'   by \code{grp}, is computed.
 #' @param grp Factor with the cross-classifying variable, where \code{dv} is
-#'        grouped into the categories represented by \code{grp}. Numeric vectors
-#'        are coerced to factors.
-#' @param weight.by Vector of weights that will be applied to weight all cases.
-#'        Must be a vector of same length as the input vector. Default is
-#'        \code{NULL}, so no weights are used.
-#' @param digits Numeric, amount of digits after decimal point when rounding estimates and values.
+#'   grouped into the categories represented by \code{grp}. Numeric vectors
+#'   are coerced to factors.
+#' @param weight.by Name of variable in \code{x} that indicated the vector of
+#'   weights that will be applied to weight all  observations. Default is
+#'   \code{NULL}, so no weights are used.
+#' @param digits Numeric, amount of digits after decimal point when rounding
+#'   estimates and values.
 #' @param out Character vector, indicating whether the results should be printed
-#'        to console (\code{out = "txt"}) or as HTML-table in the viewer-pane
-#'        (\code{out = "viewer"}) or browser (\code{out = "browser"}).
+#'   to console (\code{out = "txt"}) or as HTML-table in the viewer-pane
+#'   (\code{out = "viewer"}) or browser (\code{out = "browser"}).
 #'
 #' @return For non-grouped data frames, \code{grpmean()} returns a data frame with
-#'         following columns: \code{term}, \code{mean}, \code{N}, \code{std.dev},
-#'         \code{std.error} and \code{p.value}. For grouped data frames, returns
-#'         a list of such data frames.
+#'   following columns: \code{term}, \code{mean}, \code{N}, \code{std.dev},
+#'   \code{std.error} and \code{p.value}. For grouped data frames, returns
+#'   a list of such data frames.
 #'
 #' @details This function performs a One-Way-Anova with \code{dv} as dependent
-#'            and \code{grp} as independent variable, by calling
-#'            \code{lm(count ~ as.factor(grp))}. Then \code{\link[emmeans]{contrast}}
-#'            is called to get p-values for each sub-group. P-values indicate whether
-#'            each group-mean is significantly different from the total mean.
+#'   and \code{grp} as independent variable, by calling
+#'   \code{lm(count ~ as.factor(grp))}. Then \code{\link[emmeans]{contrast}}
+#'   is called to get p-values for each sub-group. P-values indicate whether
+#'   each group-mean is significantly different from the total mean.
 #'
 #' @examples
 #' data(efc)
@@ -42,11 +43,15 @@
 #'   group_by(c172code) %>%
 #'   grpmean(c12hour, e42dep)
 #'
+#' # weighting
+#' efc$weight <- abs(rnorm(n = nrow(efc), mean = 1, sd = .5))
+#' grpmean(efc, c12hour, e42dep, weight.by = weight)
+#'
 #' @importFrom sjlabelled get_label drop_labels get_labels
 #' @importFrom stats lm na.omit sd weighted.mean
 #' @importFrom purrr map_chr map_df
 #' @importFrom tibble tibble add_row add_column
-#' @importFrom sjmisc to_value
+#' @importFrom sjmisc to_value is_empty
 #' @importFrom rlang enquo .data quo_name
 #' @export
 grpmean <- function(x, dv, grp, weight.by = NULL, digits = 2, out = c("txt", "viewer", "browser")) {
@@ -64,11 +69,13 @@ grpmean <- function(x, dv, grp, weight.by = NULL, digits = 2, out = c("txt", "vi
   dv.name <- rlang::quo_name(rlang::enquo(dv))
 
   # weights need extra checking, might be NULL
-  if (!is.null(weight.by))
-    weights <- gsub("\"", "", deparse(substitute(weight.by)), fixed = T)
-  else
+  if (!missing(weight.by)) {
+    weights <- rlang::quo_name(rlang::enquo(weight.by))
+    if (sjmisc::is_empty(weights) || weights == "NULL") weights <- NULL
+  } else
     weights <- NULL
 
+
   # create string with variable names
   vars <- c(grp.name, dv.name, weights)
 
